@@ -1,13 +1,10 @@
+from .enum import enum_type  # noqa
 from .resolver import (  # noqa
-    async_field_resolver,
-    async_mutate,
-    async_query,
-    async_subscribe,
-    enum_resolver,
     field_resolver,
     mutate,
     query,
     subscribe,
     type_resolver,
 )
+from .scalar import scalar_type  # noqa
 from .utils import gql  # noqa
